@@ -14,7 +14,7 @@ class SentenceTransformerBackend(BaseEmbedder):
     Arguments:
         embedding_model: A sentence-transformers embedding model
 
-    Usage:
+    Examples:
 
     To create a model, you can load in a string pointing to a
     sentence-transformers model:
@@ -61,4 +61,4 @@ class SentenceTransformerBackend(BaseEmbedder):
             that each have an embeddings size of `m`
         """
         embeddings = self.embedding_model.encode(documents, show_progress_bar=verbose)
-        return embeddings
+        return embeddings
\ No newline at end of file
