@@ -1,20 +1,26 @@
 from ._topics import visualize_topics
 from ._heatmap import visualize_heatmap
 from ._barchart import visualize_barchart
+from ._documents import visualize_documents
 from ._term_rank import visualize_term_rank
 from ._hierarchy import visualize_hierarchy
 from ._distribution import visualize_distribution
 from ._topics_over_time import visualize_topics_over_time
 from ._topics_per_class import visualize_topics_per_class
+from ._hierarchical_documents import visualize_hierarchical_documents
+from ._approximate_distribution import visualize_approximate_distribution
 
 
 __all__ = [
     "visualize_topics",
     "visualize_heatmap",
     "visualize_barchart",
+    "visualize_documents",
     "visualize_term_rank",
     "visualize_hierarchy",
     "visualize_distribution",
     "visualize_topics_over_time",
-    "visualize_topics_per_class"
+    "visualize_topics_per_class",
+    "visualize_hierarchical_documents",
+    "visualize_approximate_distribution"
 ]
